@@ -1,35 +1,33 @@
-# 22-3-13  util and mq 
-import json, sys, time, fire,traceback, requests,os, pika
-from dsk import *
-from dsk.dskes import * 
+# 22-5-28  
+import json, sys, time, fire,traceback, requests,os
+import dsk,util
 
-def readline(infile, sepa=None):
-	with open(infile, 'r') as fp:
-		while True:
-			line = fp.readline()
-			if not line: break
-			yield line.strip().split(sepa) if sepa else line.strip()
+class Dsk(object):
+	def __init__(self, dskhost:str='gpu120.wrask.com:7095'): 
+		self.dskhost = dskhost
 
-def callback(ch, method, properties, body):
-	try:
-		ch.basic_ack(delivery_tag = method.delivery_tag)
-		line	= body.decode().replace(':null,',':"",')
-		dsk		= json.loads(line)
-		info	= dsk.get('info',{})
-		rid		= int(info.get('rid',0))
-		uid		= int(info.get("uid",0))
-		ver		= int(info.get('e_version',0))
-		eid		= str(info.get('essay_id',0))
-		if eid.isdigit():  # from the common source
-			eid = int(eid) 
-			submit_hdsk(dsk , rid, uid, eid , ver) 
-			index_dsk(dsk , fire.index, rid, uid, eid, ver) 
-	except Exception as ex:
-		print(">>callback Ex:", ex, time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time())), body.decode()[0:10])
-		fire.channel.close()
-		fire.connection.close()
-		exc_type, exc_value, exc_traceback_obj = sys.exc_info()
-		traceback.print_tb(exc_traceback_obj)
+	def json_to_dskmkf(self,infile, host='192.168.121.3',port=3306,user='root',password='cikuutest!',db='dskmkf', load=True):  
+		''' parse bupt.json -> dskmkf , 2022.5.28 '''
+		import pymysql 
+		conn = pymysql.connect(host=host,port=port,user=user,password=password,db=db)
+		cursor= conn.cursor()
+		with open(infile.split('.')[0] + ".dsk", 'w') as fw: 
+			for line in util.readline(infile) : #open(infile, 'r').readlines(): 
+				try:
+					arr = json.loads(line)
+					essay = arr.get("essay", "") 
+					if not essay: continue 
+					dsk = localgec_todsk(essay, dskhost=self.dskhost)
+					dsk['info'].update({"essay_id": arr.get("essay_id", 0), "rid": arr.get("request_id", 0), "uid": arr.get("user_id",0), "e_version": arr.get("version",0) })
+					dsk.submit_dskmkf(dsk, cursor)	 #eid,rid,uid,ver = int( info.get('essay_id',0) ),int( info.get('rid',0) ),int( info.get('uid',0) ),int( info.get('e_version',0) )
+					conn.commit()
+				except Exception as e:
+					print (e) 
+		print("finished parsing:", infile)
+
+	def localgec_todsk(self, essay:str="She has ready. It are ok."): 
+		''' test localgec todsk '''
+		print (localgec_todsk(essay, dskhost=self.dskhost))
 
 class util(object):
 	def __init__(self): pass
@@ -104,12 +102,34 @@ class util(object):
 
 	def consume(self, queue_name, mhost='127.0.0.1', mport=5672, user='guest', pwd='guest', heartbeat=60, durable=True, idxname='dskes', debug=False ):
 		''' rabbitmq consumer  '''
+		import pika
 		credentials = pika.PlainCredentials(user, pwd)  
 		fire.connection = pika.BlockingConnection(pika.ConnectionParameters(host = mhost,port = mport,virtual_host = '/',credentials = credentials, heartbeat=heartbeat))
 		fire.channel= fire.connection.channel()
 		fire.index = idxname
 		fire.debug = debug
 
+		def callback(ch, method, properties, body):
+			try:
+				ch.basic_ack(delivery_tag = method.delivery_tag)
+				line	= body.decode().replace(':null,',':"",')
+				dsk		= json.loads(line)
+				info	= dsk.get('info',{})
+				rid		= int(info.get('rid',0))
+				uid		= int(info.get("uid",0))
+				ver		= int(info.get('e_version',0))
+				eid		= str(info.get('essay_id',0))
+				if eid.isdigit():  # from the common source
+					eid = int(eid) 
+					submit_hdsk(dsk , rid, uid, eid , ver) 
+					index_dsk(dsk , fire.index, rid, uid, eid, ver) 
+			except Exception as ex:
+				print(">>callback Ex:", ex, time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time())), body.decode()[0:10])
+				fire.channel.close()
+				fire.connection.close()
+				exc_type, exc_value, exc_traceback_obj = sys.exc_info()
+				traceback.print_tb(exc_traceback_obj)
+
 		result = fire.channel.queue_declare(queue = queue_name, durable=durable) 
 		print("queue is :", queue_name, flush=True)
 		fire.channel.basic_consume(queue_name, callback) #mapf[queue_name] #mapf = { "dsk-dm": dskdm, }
@@ -117,4 +137,4 @@ class util(object):
 		#fire.connection.close()
 
 if __name__ == '__main__': 
-	fire.Fire(util) 
\ No newline at end of file
+	fire.Fire(Dsk) 
\ No newline at end of file
